import axios, { InternalAxiosRequestConfig, AxiosResponse } from "axios";
import { useUserStoreHook } from "@/store/modules/user";
import { ResultEnum } from "@/enums/ResultEnum";
import { TOKEN_KEY, CODE_KEY, CODE_NAME } from "@/enums/CacheEnum";
import jsonBig from "json-bigint";
// 创建 axios 实例
const service = axios.create({
  baseURL: import.meta.env.VITE_APP_BASE_API,
  timeout: 50000,
  headers: {
    "Access-Control-Allow-Origin": "*",
    "Content-Type": "application/json;charset=utf-8",
  },
  transformResponse: [
    function (data) {
      //transformResponse这个配置项可以拦截接口返回的内容进行处理
      if (
        data.type === "application/vnd.ms-excel" ||
        data.type === "text/xml"
      ) {
        return data;
      } else {
        try {
          // 如果大数字类型转换成功则返回转换的数据结果
          return jsonBig.parse(data);
        } catch (err) {
          // 如果转换失败，代表没有长数字可转，正常解析并返回
          return JSON.parse(data);
        }
      }
    },
  ],
});

// 请求拦截器
service.interceptors.request.use(
  (config: InternalAxiosRequestConfig) => {
    const accessToken = localStorage.getItem(TOKEN_KEY);
    if (accessToken) {
      config.headers["x-userToken"] = accessToken;
    }
    if (config.url && config.url.indexOf("/api/db/getCommonDbPhone") === -1) {
      const codeKey = localStorage.getItem(CODE_KEY);
      if (codeKey) {
        config.headers[CODE_KEY] = codeKey;
      }
      const codeName = localStorage.getItem(CODE_NAME);
      if (codeName) {
        config.headers[CODE_NAME] = codeName;
      }
    }
    return config;
  },
  (error: any) => {
    return Promise.reject(error);
  }
);

// 响应拦截器
service.interceptors.response.use(
  (response: AxiosResponse) => {
    // 检查配置的响应类型是否为二进制类型（'blob' 或 'arraybuffer'）, 如果是，直接返回响应对象
    if (
      response.headers["content-type"].indexOf("application/vnd.ms-excel") > -1
    ) {
      return response.data;
    }

    const { code, data, message } = response.data;
    if (code === ResultEnum.SUCCESS) {
      return data;
    }

    ElMessage.error(message || "系统出错");
    return Promise.reject(new Error(message || "Error"));
  },
  (error: any) => {
    // 异常处理
    if (error.response.data) {
      const { code, message } = error.response.data;
      if (code === ResultEnum.TOKEN_INVALID) {
        ElNotification({
          title: "提示",
          message: "您的会话已过期，请重新登录",
          type: "info",
        });
        useUserStoreHook()
          .resetToken()
          .then(() => {
            location.reload();
          });
      } else {
        ElMessage.error(message || "系统出错");
      }
    }
    return Promise.reject(error.message);
  }
);

// 导出 axios 实例
export default service;
